@@ -168,8 +168,9 @@
 			},
 
 			// Reload a term after properties change
-			reloadTerm: function(source) {
+			reloadTerm: function(options) {
 				$.ZTFY.dialog.close();
+				var source = options.source;
 				var img = $('IMG.plminus:first', $("A:econtains(" + source.replace('&#039;','\'') + ")").closest('DIV'));
 				$.ZTFY.thesaurus.tree.collapse(img);
 				$.ZTFY.thesaurus.tree.expand(img);
