@@ -34,6 +34,7 @@ from ztfy.skin.form import DialogAddForm, DialogEditForm
 from ztfy.skin.menu import DialogMenuItem
 from ztfy.thesaurus.browser.tree import ThesaurusTermsTreeView
 from ztfy.thesaurus.term import ThesaurusTerm
+from ztfy.utils.request import setRequestData, getRequestData
 from ztfy.utils.traversing import getParent
 
 from ztfy.thesaurus import _
@@ -59,7 +60,9 @@ class ThesaurusTermAddForm(DialogAddForm):
         thesaurus = IThesaurus(self.context)
         if data.get('label') in thesaurus.terms:
             raise ValueError, _("The given label is already used in this thesaurus !")
-        return ThesaurusTerm(data.get('label'))
+        result = ThesaurusTerm(data.get('label'))
+        setRequestData('thesaurus.new_term', result, self.request)
+        return result
 
     def add(self, term):
         thesaurus = IThesaurus(self.context)
@@ -75,7 +78,13 @@ class ThesaurusTermAddForm(DialogAddForm):
             generic.specifics = generic.specifics + [term, ]
 
     def getOutput(self, writer, parent):
-        return writer.write({ 'output': u'RELOAD' })
+        term = getRequestData('thesaurus.new_term', self.request)
+        if (term is None) or not term.generic:
+            return writer.write({ 'output': u'RELOAD' })
+        else:
+            return writer.write({ 'output': u'CALLBACK',
+                                  'callback': '$.ZTFY.thesaurus.tree.reloadTerm',
+                                  'options': { 'source': term.generic.label.replace("'", "&#039;") } })
 
 
 class ThesaurusTermAddMenuItem(DialogMenuItem):
@@ -147,20 +156,22 @@ class ThesaurusTermEditForm(DialogEditForm):
         return changes
 
     def getOutput(self, writer, parent, changes=()):
+        callback = None
+        options = None
         if self._v_generic_changed:
             status = u'RELOAD'
-            callback = None
         else:
             if 'label' in changes.get(IThesaurusTermInfo, []):
                 term = self.getContent()
                 generic = term.generic
                 if generic is None:
                     status = u'RELOAD'
-                    callback = None
                 else:
                     status = u'CALLBACK'
-                    callback = """$.ZTFY.thesaurus.tree.reloadTerm("%s");""" % generic.label.replace("'", "&#039;")
+                    callback = '$.ZTFY.thesaurus.tree.reloadTerm'
+                    options = { 'source': generic.label.replace("'", "&#039;") }
             else:
                 status = changes and u'OK' or u'NONE'
-                callback = None
-        return writer.write({ 'output': status, 'callback': callback })
+        return writer.write({ 'output': status,
+                              'callback': callback,
+                              'options': options })
