@@ -62,7 +62,8 @@ from zope.traversing import api as traversing_api
 from zope.traversing.browser import absoluteURL
 
 # import local packages
-from ztfy.jqueryui import jquery_multiselect, jquery_colorpicker
+from ztfy.jqueryui import jquery_multiselect, jquery_colorpicker, \
+    jquery_datetime
 from ztfy.security.browser.roles import RolesEditForm
 from ztfy.skin.container import ContainerBaseView
 from ztfy.skin.form import DialogAddForm, EditForm, DialogEditForm
@@ -71,7 +72,7 @@ from ztfy.thesaurus.browser import ztfy_thesaurus
 from ztfy.thesaurus.loader.config import ThesaurusLoaderConfiguration, \
                                          ThesaurusUpdaterConfiguration, \
                                          ThesaurusExporterConfiguration
-from ztfy.thesaurus.thesaurus import ThesaurusExtract
+from ztfy.thesaurus.thesaurus import ThesaurusExtract, Thesaurus
 from ztfy.utils.container import getContentName
 from ztfy.utils.list import unique
 from ztfy.utils.traversing import getParent
@@ -197,7 +198,40 @@ def ThesaurusAutomaticSelectWidgetFactory(field, request):
 class ThesaurusAddForm(DialogAddForm):
     """Thesaurus add form"""
 
-    legend = _("Adding and registering a new thesaurus")
+    legend = _("Adding a new empty thesaurus")
+
+    layout = getLayoutTemplate()
+    parent_interface = IThesaurusManagerTarget
+    parent_view = ThesaurusListView
+
+    fields = field.Fields(IThesaurusInfo).select('name', 'title', 'subject', 'description', 'language',
+                                                 'creator', 'publisher', 'created')
+    resources = (jquery_datetime,)
+
+    def create(self, data):
+        thesaurus = Thesaurus()
+        thesaurus.name = data.get('name')
+        return thesaurus
+
+    def add(self, thesaurus):
+        manager = getSiteManager(self.context)
+        default = manager['default']
+        default['Thesaurus::' + thesaurus.name] = thesaurus
+        manager.registerUtility(removeSecurityProxy(thesaurus), IThesaurus, thesaurus.name)
+        locate(thesaurus, removeSecurityProxy(self.context), '++thesaurus++' + thesaurus.name)
+
+
+class ThesaurusAddMenuItem(DialogMenuItem):
+    """Thesaurus add menu item"""
+
+    title = _(":: Add empty thesaurus...")
+    target = ThesaurusAddForm
+
+
+class ThesaurusImportForm(DialogAddForm):
+    """Thesaurus import form"""
+
+    legend = _("Importing and registering a new thesaurus")
 
     layout = getLayoutTemplate()
     parent_interface = IThesaurusManagerTarget
@@ -229,11 +263,11 @@ class ThesaurusAddForm(DialogAddForm):
         locate(thesaurus, removeSecurityProxy(self.context), '++thesaurus++' + thesaurus.name)
 
 
-class ThesaurusAddMenuItem(DialogMenuItem):
+class ThesaurusImportMenuItem(DialogMenuItem):
     """Thesaurus add menu item"""
 
-    title = _(":: Add thesaurus")
-    target = ThesaurusAddForm
+    title = _(":: Import thesaurus...")
+    target = ThesaurusImportForm
 
 
 class ThesaurusEditForm(EditForm):
