@@ -32,9 +32,13 @@ from ztfy.thesaurus.schema import ThesaurusTermField, ThesaurusTermsListField, V
 from ztfy.thesaurus import _
 
 
-THESAURUS_STATUS = (u'candidate',
-                    u'published',
-                    u'archived')
+STATUS_CANDIDATE = u'candidate'
+STATUS_PUBLISHED = u'published'
+STATUS_ARCHIVED = u'archived'
+
+THESAURUS_STATUS = (STATUS_CANDIDATE,
+                    STATUS_PUBLISHED,
+                    STATUS_ARCHIVED)
 
 THESAURUS_STATUS_LABELS = (_("Candidate"),
                            _("Published"),
