@@ -15,8 +15,8 @@
 
 
 # import standard packages
-from persistent import Persistent
 from datetime import datetime
+from persistent import Persistent
 
 # import Zope3 interfaces
 
@@ -79,16 +79,16 @@ class ThesaurusTerm(Persistent, Contained):
         if other is None:
             return False
         else:
-            return isinstance(other, ThesaurusTerm) and (self.label == other.label)
+            return isinstance(removeSecurityProxy(other), ThesaurusTerm) and (self.label == other.label)
 
     @property
     def caption(self):
         if self._usage:
-            return '%s [%s]' % (self._usage.label,
-                                ', '.join((term.label for term in self._usage._used_for)))
+            return '%s [ %s ]' % (self._usage.label,
+                                  ', '.join((term.label for term in self._usage._used_for)))
         elif self._used_for:
-            return '%s [%s]' % (self.label,
-                                ', '.join((term.label for term in self._used_for)))
+            return '%s [ %s ]' % (self.label,
+                                  ', '.join((term.label for term in self._used_for)))
         else:
             return self.label
 
